import type { Bud } from '@roots/bud-framework';
import { Extension } from '@roots/bud-framework/extension';
import type { LoaderOptions, Registry } from './types.js';
/**
 * Babel support for `@roots/bud`
 *
 * @public
 * @decorator `@label`
 * @decorator `@expose`
 */
export default class BabelExtension extends Extension {
    /**
     * Cache directory
     */
    get cacheDirectory(): LoaderOptions[`cacheDirectory`];
    /**
     * Babel env
     */
    env: LoaderOptions[`env`];
    getEnv(): LoaderOptions[`env`];
    setEnv(env: LoaderOptions[`env`]): this;
    /**
     * Plugins registry
     */
    plugins: Registry;
    /**
     * Presets registry
     */
    presets: Registry;
    /**
     * Root directory
     */
    get root(): string;
    /**
     * Loader options
     *
     * @readonly
     */
    get loaderOptions(): LoaderOptions;
    /**
     * {@link Extension.register}
     */
    register(): Promise<void>;
    /**
     * {@link Extension.configAfter}
     */
    configAfter(bud: Bud): Promise<void>;
    /**
     * Set a babel preset
     */
    setPreset(name: string, preset?: [string, any] | string): this;
    /**
     * Set babel presets
     */
    setPresets(presets: {
        [key: string]: [string, any] | string;
    }): this;
    /**
     * Remove a babel preset
     */
    unsetPreset(preset: string): this;
    /**
     * Set options on a babel preset
     */
    setPresetOptions(preset: string, options: any): this;
    /**
     * Set a babel plugin
     */
    setPlugin(name: string | [any, any], plugin?: [any, any] | string): this;
    /**
     * Set babel presets
     */
    setPlugins(plugins: {
        [key: string]: [any, any] | string;
    }): this;
    /**
     * Remove a babel plugin
     */
    unsetPlugin(plugin: string): this;
    /**
     * Set options on a babel plugin
     */
    setPluginOptions(plugin: string, options: any): this;
}
//# sourceMappingURL=extension.d.ts.map